==> Task-BeLike-BURAK-0.10.tar.gz: Task-BeLike-BURAK-0.10/lib/Task/BeLike/BURAK.pm <==
package Task::BeLike::BURAK;
use strict;
use warnings;
use vars qw( $VERSION );

$VERSION = '0.10';

1;

__END__

=pod

=head1 NAME

Task::Lingua::Any::Numbers - Installs all modules I (BURAK) like

=head1 SYNOPSIS

None.

=head1 DESCRIPTION

This document describes version C<0.10> of C<Task::BeLike::BURAK>
released on C<20 February 2011>.

This is a tool to install module I use.

=head1 PREREQUISITIES

=head2 MY MODULES

=head3 L<Acme::CPANAuthors::Turkish>

=head3 L<App::Sys::Info>

=head3 L<CGI::Auth::Basic>

=head3 L<Device::CableModem::Motorola::SB4200>

=head3 L<GD::SecurityImage>

=head3 L<GD::Thumbnail>

=head3 L<Lingua::TR::ASCII>

=head3 L<MP3::M3U::Parser>

=head3 L<Parse::HTTP::UserAgent>

=head3 L<PHP::Session::DBI>

=head3 L<Scalar::Util::Reftype>

=head3 L<Task::Lingua::Any::Numbers>

=head3 L<Test::Sys::Info>

=head3 L<Text::Template::Simple>

=head3 L<Time::Elapsed>

=head3 L<Win32::ASP::CGI>

System specific.

=head2 UTILITY

=head3 L<criticism>

=head3 L<Devel::Size>

=head3 L<File::HomeDir>

=head3 L<Perl::Tidy>

=head3 L<Test::Pod>

=head3 L<Test::Pod::Coverage>

=head3 L<Text::Table>

=head2 GUI

=head3 L<Tk>

=head2 WEB

=head3 L<HTML::Parser>

=head3 L<Mojolicious>

=head2 SYSTEM SPECIFIC

=head3 L<Win32::API>

=head1 AUTHOR

Burak Gursoy <burak@cpan.org>.

=head1 COPYRIGHT

Copyright 2011 Burak Gursoy. All rights reserved.

=head1 LICENSE

This library is free software; you can redistribute it and/or modify 
it under the same terms as Perl itself, either Perl version 5.10.0 or, 
at your option, any later version of Perl 5 you may have available.

=cut

==> Task-BeLike-BURAK-0.11.tar.gz: Task-BeLike-BURAK-0.11/lib/Task/BeLike/BURAK.pm <==
package Task::BeLike::BURAK;
use strict;
use warnings;
use vars qw( $VERSION );

$VERSION = '0.11';

1;

__END__

=pod

=head1 NAME

Task::Lingua::Any::Numbers - Installs all modules I (BURAK) like

=head1 SYNOPSIS

None.

=head1 DESCRIPTION

This document describes version C<0.11> of C<Task::BeLike::BURAK>
released on C<3 April 2011>.

This is a tool to install module I use.

=head1 PREREQUISITIES

=head2 DATE MANIPULATION

=head3 L<DateTime>

=head3 L<DateTime::Format::W3CDTF>

=head3 L<DateTime::Format::Mail>

=head2 MY MODULES

=head3 L<Acme::CPANAuthors::Turkish>

=head3 L<App::Sys::Info>

=head3 L<CGI::Auth::Basic>

=head3 L<Device::CableModem::Motorola::SB4200>

=head3 L<GD::SecurityImage>

=head3 L<GD::Thumbnail>

=head3 L<Lingua::TR::ASCII>

=head3 L<MP3::M3U::Parser>

=head3 L<Parse::HTTP::UserAgent>

=head3 L<PHP::Session::DBI>

=head3 L<Scalar::Util::Reftype>

=head3 L<Task::Lingua::Any::Numbers>

=head3 L<Test::Sys::Info>

=head3 L<Text::Template::Simple>

=head3 L<Time::Elapsed>

=head3 L<Win32::ASP::CGI>

System specific.

=head2 UTILITY

=head3 L<criticism>

=head3 L<Devel::Size>

=head3 L<File::HomeDir>

=head3 L<Perl::Tidy>

=head3 L<Test::Pod>

=head3 L<Test::Pod::Coverage>

=head3 L<Text::Table>

=head2 GUI

=head3 L<Tk>

=head2 WEB

=head3 L<HTML::Parser>

=head3 L<LWP::UserAgent>

=head3 L<Mojolicious>

=head2 SYSTEM SPECIFIC

=head3 L<Win32::API>

=head2 XML

=head3 L<XML::RSS>

=head3 L<XML::Simple>

=head1 AUTHOR

Burak Gursoy <burak@cpan.org>.

=head1 COPYRIGHT

Copyright 2011 Burak Gursoy. All rights reserved.

=head1 LICENSE

This library is free software; you can redistribute it and/or modify 
it under the same terms as Perl itself, either Perl version 5.12.1 or, 
at your option, any later version of Perl 5 you may have available.

=cut
